# Control Mini-Circuits' RUDAT or RCDAT series programmable attenuators via USB
# Requirements:
#   1: Python.Net (pip install pythonnet)
#   2: Mini-Circuits' DLL API file (mcl_RUDAT_NET45.dll)
#      https://www.minicircuits.com/softwaredownload/mcl_RUDAT64_DLL.zip
#      Note: - Windows may block the DLL file after download as a precaution
#            - Right-click on the file, select properties, click "Unblock" (if shown)

import clr # pythonnet
clr.AddReference('mcl_RUDAT_NET45')      # Reference the DLL

from mcl_RUDAT_NET45 import USB_RUDAT
att = USB_RUDAT()   # Create an instance of the USB control class

Status = att.Connect()       # Connect (pass the serial number as an argument if required)

if Status > 0:              # The connection was successful

    Responses = att.Send_SCPI(":SN?", "")        # Read serial number
    print (str(Responses[1]))   # Python interprets the response as a tuple [function return (0 or 1), command parameter, response parameter]

    Responses = att.Send_SCPI(":MN?", "")        # Read model name
    print (str(Responses[1]))

    # Set and then read attenuation (single channel models)
    Status = att.Send_SCPI(":SETATT=12.75", "")    # Set attenuation
    Responses = att.Send_SCPI(":ATT?", "")   # Read attenuation
    print (str(Responses[1]))

    # Set and then read attenuation (multi-channel models)
    #Status = att.Send_SCPI(":CHAN:1:SETATT:0", "")          # Set attenuation (channel 1)
    #Status = att.Send_SCPI(":CHAN:2:3:4:SETATT:10.25", "")    # Set attenuation (channels 2-4)
    #Responses = att.Send_SCPI(":ATT?", "")   # Read attenuation
    #print (str(Responses[1]))

    att.Disconnect()             # Disconnect at the end of the program

else:
    print ("Could not connect.")
